summaryrefslogtreecommitdiffstats
path: root/part/kxeconfiguration.h
diff options
context:
space:
mode:
Diffstat (limited to 'part/kxeconfiguration.h')
-rw-r--r--part/kxeconfiguration.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/part/kxeconfiguration.h b/part/kxeconfiguration.h
index a0569c8..44acfe7 100644
--- a/part/kxeconfiguration.h
+++ b/part/kxeconfiguration.h
@@ -26,7 +26,7 @@ class KXENewFileSettings;
class KXEPrintSettings;
class KXEArchiveExtsSettings;
-class KConfig;
+class TDEConfig;
class KDialogBase;
/**
@@ -57,19 +57,19 @@ class KXEConfiguration : public TQObject
~KXEConfiguration();
/**
* Stores all configuration to the given @ref KConfig object by
* using @ref KXESettings's @ref store function.
* If no @ref KConfig object is given, @ref KGlobal::config is
* used.
*/
- void store( KConfig * pConfig = 0 ) const;
+ void store( TDEConfig * pConfig = 0 ) const;
/**
* Restores all configuration from the given @ref KConfig object
* by using @ref KXESettings's @ref restore function.
* If no @ref KConfig object is given, @ref KGlobal::config is
* used.
*/
- void restore( KConfig * pConfig = 0 );
+ void restore( TDEConfig * pConfig = 0 );
/**
* Shows the configuration dialog.
* If there is no one yet, it is created by.
@@ -57,19 +57,19 @@ class KXEConfiguration : public TQObject
~KXEConfiguration();
/**
- * Stores all configuration to the given @ref KConfig object by
+ * Stores all configuration to the given @ref TDEConfig object by
* using @ref KXESettings's @ref store function.
@@ -57,19 +57,19 @@ class KXEConfiguration : public TQObject
* using @ref KXESettings's @ref store function.
- * If no @ref KConfig object is given, @ref KGlobal::config is
+ * If no @ref TDEConfig object is given, @ref TDEGlobal::config is
* used.
*/
@@ -57,19 +57,19 @@ class KXEConfiguration : public TQObject
/**
- * Restores all configuration from the given @ref KConfig object
+ * Restores all configuration from the given @ref TDEConfig object
* by using @ref KXESettings's @ref restore function.
@@ -57,19 +57,19 @@ class KXEConfiguration : public TQObject
* by using @ref KXESettings's @ref restore function.
- * If no @ref KConfig object is given, @ref KGlobal::config is
+ * If no @ref TDEConfig object is given, @ref TDEGlobal::config is
* used.
*/